==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_flipgroup_list/main.tf <==
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator  = "oauth2"
  oauth2_url     = "https://sso.digitalenergy.online"
  controller_url = "https://mr4.digitalenergy.online"
  app_id         = ""
  app_secret     = ""
}

data "decort_flipgroup_list" "fg" {
  #фильтр по id flipgroup 
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "fg_out" {
  value = data.decort_flipgroup_list.fg
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_flipgroup_list/main.tf <==
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_flipgroup_list" "fg" {
  #фильтр по id flipgroup 
  #опциональный параметр
  #тип - число
  #by_id = 100

  #фильтр по имени flipgroup
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #vins_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #vins_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #фильтр по IP
  #опциональный параметр
  #тип - строка
  #by_ip = "1.1.1.1.1"

  #id ресурсной группы, используется для фильтрации
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #rg_id = 11111

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3
}

output "fg_out" {
  value = data.decort_flipgroup_list.fg
}
